@@ -8,7 +8,7 @@ use crate::store::Store;
 use crate::types::array::Array;
 use crate::types::xml::{XmlElement, XmlText};
 use crate::types::{
-    BranchPtr, Map, Text, TypePtr, TYPE_REFS_ARRAY, TYPE_REFS_MAP, TYPE_REFS_TEXT,
+    BranchPtr, Event, Events, Map, Text, TypePtr, TYPE_REFS_ARRAY, TYPE_REFS_MAP, TYPE_REFS_TEXT,
     TYPE_REFS_XML_ELEMENT, TYPE_REFS_XML_TEXT,
 };
 use crate::update::Update;
@@ -150,7 +150,7 @@ impl Transaction {
     pub fn get_xml_element(&mut self, name: &str) -> XmlElement {
         let c = self.store_mut().get_or_create_type(
             name,
-            Some("UNDEFINED".to_string()),
+            Some("UNDEFINED".into()),
             TYPE_REFS_XML_ELEMENT,
         );
         XmlElement::from(c)
@@ -201,6 +201,22 @@ impl Transaction {
         self.delete_set.encode(encoder);
     }
 
+    /// Encodes the document state to a binary format.
+    ///
+    /// Document updates are idempotent and commutative. Caveats:
+    /// * It doesn't matter in which order document updates are applied.
+    /// * As long as all clients receive the same document updates, all clients
+    ///   end up with the same content.
+    /// * Even if an update contains known information, the unknown information
+    ///   is extracted and integrated into the document structure.
+    pub fn encode_update_v2(&self) -> Vec<u8> {
+        let mut enc = updates::encoder::EncoderV2::new();
+        let store = self.store();
+        store.write_blocks(&self.before_state, &mut enc);
+        self.delete_set.encode(&mut enc);
+        enc.to_vec()
+    }
+
     /// Applies given `id_set` onto current transaction to run multi-range deletion.
     /// Returns a remaining of original ID set, that couldn't be applied.
     pub(crate) fn apply_delete(&mut self, ds: &DeleteSet) -> Option<DeleteSet> {
@@ -307,7 +323,8 @@ impl Transaction {
                     }
                     ItemContent::Type(inner) => {
                         let mut ptr = inner.start;
-                        //TODO: self.changed.remove(&item.parent); // uncomment when deep observe is complete
+                        self.changed
+                            .remove(&TypePtr::Branch(BranchPtr::from(inner)));
 
                         while let Some(Block::Item(item)) = ptr.as_deref() {
                             if !item.is_deleted() {
@@ -472,13 +489,53 @@ impl Transaction {
         // 2. emit 'beforeObserverCalls'
         // 3. for each change observed by the transaction call 'afterTransaction'
         if !self.changed.is_empty() {
+            let mut changed_parents: HashMap<BranchPtr, Vec<usize>> = HashMap::new();
+            let mut event_cache = Vec::new();
+
             for (ptr, subs) in self.changed.iter() {
                 if let TypePtr::Branch(branch) = ptr {
-                    if let Some(o) = branch.observers.as_ref() {
-                        o.publish(branch.clone(), self, subs.clone());
+                    if let Some(e) = branch.trigger(self, subs.clone()) {
+                        event_cache.push(e);
+
+                        let mut current = *branch;
+                        loop {
+                            if current.deep_observers.is_some() {
+                                let entries = changed_parents.entry(current).or_default();
+                                entries.push(event_cache.len() - 1);
+                            }
+
+                            if let Some(Block::Item(item)) = current.item.as_deref() {
+                                if let TypePtr::Branch(parent) = item.parent {
+                                    current = parent;
+                                    continue;
+                                }
+                            }
+
+                            break;
+                        }
                     }
                 }
             }
+
+            // deep observe events
+            for (&branch, events) in changed_parents.iter() {
+                // sort events by path length so that top-level events are fired first.
+                let mut unsorted: Vec<&Event> = Vec::with_capacity(events.len());
+
+                for &i in events.iter() {
+                    let e = &mut event_cache[i];
+                    e.set_current_target(branch);
+                }
+
+                for &i in events.iter() {
+                    unsorted.push(&event_cache[i]);
+                }
+
+                // We don't need to check for events.length
+                // because we know it has at least one element
+                let events = Events::new(&mut unsorted);
+                branch.trigger_deep(self, &events);
+            }
         }
 
         // 4. try GC delete set
@@ -553,7 +610,7 @@ impl Transaction {
 
     pub(crate) fn add_changed_type(&mut self, parent: BranchPtr, parent_sub: Option<Rc<str>>) {
         let trigger = if let Some(ptr) = parent.item {
-            (ptr.id().clock < (self.before_state.get(&ptr.id().client))) && ptr.is_deleted()
+            (ptr.id().clock < self.before_state.get(&ptr.id().client)) && !ptr.is_deleted()
         } else {
             true
         };
@@ -574,13 +631,16 @@ impl Transaction {
     }
 
     pub(crate) fn split_by_snapshot(&mut self, snapshot: &Snapshot) {
+        let mut merge_blocks = Vec::new();
         let blocks = &mut self.store_mut().blocks;
         for (client, &clock) in snapshot.state_map.iter() {
             if let Some(list) = blocks.get(client) {
                 if let Some(ptr) = list.get_block(clock) {
                     let ptr_clock = ptr.id().clock;
                     if ptr_clock < clock {
-                        blocks.split_block(ptr, clock - ptr_clock);
+                        if let Some(ptr) = blocks.split_block(ptr, clock - ptr_clock) {
+                            merge_blocks.push(ptr);
+                        }
                     }
                 }
             }
@@ -593,7 +653,9 @@ impl Transaction {
                         let block = list.get(pivot);
                         let clock = block.id().clock;
                         if clock < r.start {
-                            blocks.split_block(block, r.start - clock);
+                            if let Some(ptr) = blocks.split_block(block, r.start - clock) {
+                                merge_blocks.push(ptr);
+                            }
                             list = blocks.get(client).unwrap();
                         }
                     }
@@ -603,13 +665,19 @@ impl Transaction {
                         let block_id = block.id();
                         let block_len = block.len();
                         if block_id.clock + block_len > r.end {
-                            blocks.split_block(block, block_id.clock + block_len - r.end);
+                            if let Some(ptr) =
+                                blocks.split_block(block, block_id.clock + block_len - r.end)
+                            {
+                                merge_blocks.push(ptr);
+                            }
                             list = blocks.get(client).unwrap();
                         }
                     }
                 }
             }
         }
+
+        self.merge_blocks.append(&mut merge_blocks);
     }
 }
 
