@@ -7,7 +7,7 @@ use crate::*;
 use lib0::any::Any;
 use std::cell::UnsafeCell;
 use std::collections::{HashMap, HashSet};
-use std::ops::Deref;
+use std::ops::{Deref, DerefMut};
 use std::rc::Rc;
 
 /// Collection used to store key-value entries in an unordered manner. Keys are always represented
@@ -165,6 +165,12 @@ impl AsRef<Branch> for Map {
     }
 }
 
+impl AsMut<Branch> for Map {
+    fn as_mut(&mut self) -> &mut Branch {
+        self.0.deref_mut()
+    }
+}
+
 pub struct MapIter<'a>(Entries<'a>);
 
 impl<'a> Iterator for MapIter<'a> {
@@ -214,6 +220,12 @@ impl From<BranchPtr> for Map {
 /// to be inserted into another Yrs collection, such as [Array] or another [Map].
 pub struct PrelimMap<T>(HashMap<String, T>);
 
+impl<T> PrelimMap<T> {
+    pub fn new() -> Self {
+        PrelimMap(HashMap::default())
+    }
+}
+
 impl<T> From<HashMap<String, T>> for PrelimMap<T> {
     fn from(map: HashMap<String, T>) -> Self {
         PrelimMap(map)
@@ -236,8 +248,8 @@ impl<T: Prelim> Prelim for PrelimMap<T> {
 
 /// Event generated by [Map::observe] method. Emitted during transaction commit phase.
 pub struct MapEvent {
+    pub(crate) current_target: BranchPtr,
     target: Map,
-    current_target: BranchPtr,
     keys: UnsafeCell<Result<HashMap<Rc<str>, EntryChange>, HashSet<Option<Rc<str>>>>>,
 }
 
@@ -286,16 +298,17 @@ impl MapEvent {
 #[cfg(test)]
 mod test {
     use crate::test_utils::{exchange_updates, run_scenario};
-    use crate::types::{EntryChange, Map, Value};
+    use crate::types::{DeepObservable, EntryChange, Event, Map, Path, PathSegment, Value};
     use crate::updates::decoder::Decode;
     use crate::updates::encoder::{Encoder, EncoderV1};
-    use crate::{Doc, PrelimArray, PrelimMap, Update};
+    use crate::{Doc, PrelimArray, PrelimMap, StateVector, Update};
     use lib0::any::Any;
     use rand::distributions::Alphanumeric;
     use rand::prelude::{SliceRandom, StdRng};
     use rand::Rng;
     use std::cell::RefCell;
     use std::collections::HashMap;
+    use std::ops::{Deref, DerefMut};
     use std::rc::Rc;
 
     #[test]
@@ -348,7 +361,7 @@ mod test {
 
         compare_all(&m1);
 
-        let update = t1.encode_update_v1(); // d1.encode_state_as_update_v1
+        let update = d1.encode_state_as_update_v1(&StateVector::default());
         t2.apply_update(Update::decode_v1(update.as_slice()));
 
         compare_all(&m2);
@@ -363,7 +376,7 @@ mod test {
         m1.insert(&mut t1, "stuff".to_owned(), "stuffy");
         m1.insert(&mut t1, "null".to_owned(), None as Option<String>);
 
-        let update = t1.encode_update_v1(); //d1.encode_state_as_update_v1(&t1);
+        let update = d1.encode_state_as_update_v1(&StateVector::default());
 
         let d2 = Doc::with_client_id(2);
         let mut t2 = d2.transact();
@@ -388,8 +401,8 @@ mod test {
         m1.insert(&mut t1, "stuff".to_owned(), "c0");
         m2.insert(&mut t2, "stuff".to_owned(), "c1");
 
-        let u1 = t1.encode_update_v1(); //d1.encode_state_as_update_v1(&t1);
-        let u2 = t2.encode_update_v1(); //d2.encode_state_as_update_v1(&t2);
+        let u1 = d1.encode_state_as_update_v1(&StateVector::default());
+        let u2 = d2.encode_state_as_update_v1(&StateVector::default());
 
         t1.apply_update(Update::decode_v1(u2.as_slice()));
         t2.apply_update(Update::decode_v1(u1.as_slice()));
@@ -441,7 +454,7 @@ mod test {
         let d2 = Doc::with_client_id(2);
         let mut t2 = d2.transact();
 
-        let u1 = t1.encode_update_v1(); //d1.encode_state_as_update_v1(&t1);
+        let u1 = d1.encode_state_as_update_v1(&StateVector::default());
         t2.apply_update(Update::decode_v1(u1.as_slice()));
 
         let m2 = t2.get_map("map");
@@ -791,4 +804,46 @@ mod test {
     fn fuzzy_test_6() {
         fuzzy(6)
     }
+
+    #[test]
+    fn observe_deep() {
+        let doc = Doc::with_client_id(1);
+        let mut map = doc.transact().get_map("map");
+
+        let paths = Rc::new(RefCell::new(vec![]));
+        let calls = Rc::new(RefCell::new(0));
+        let paths_copy = paths.clone();
+        let calls_copy = calls.clone();
+        let _sub = map.observe_deep(move |_txn, e| {
+            let path: Vec<Path> = e.iter().map(Event::path).collect();
+            paths_copy.borrow_mut().push(path);
+            let mut count = calls_copy.borrow_mut();
+            let count = count.deref_mut();
+            *count += 1;
+        });
+
+        map.insert(&mut doc.transact(), "map", PrelimMap::<String>::new());
+        let nested = map.get("map").unwrap().to_ymap().unwrap();
+        nested.insert(
+            &mut doc.transact(),
+            "array",
+            PrelimArray::from(Vec::<String>::default()),
+        );
+        let nested2 = nested.get("array").unwrap().to_yarray().unwrap();
+        nested2.insert(&mut doc.transact(), 0, "content");
+
+        assert_eq!(*calls.borrow().deref(), 3);
+        let actual = paths.borrow();
+        assert_eq!(
+            actual.as_slice(),
+            &[
+                vec![Path::from(vec![])],
+                vec![Path::from(vec![PathSegment::Key("map".into())])],
+                vec![Path::from(vec![
+                    PathSegment::Key("map".into()),
+                    PathSegment::Key("array".into())
+                ])],
+            ]
+        );
+    }
 }
