@@ -11,7 +11,7 @@ use lib0::any::Any;
 use std::cell::UnsafeCell;
 use std::collections::{HashMap, HashSet};
 use std::fmt::Write;
-use std::ops::Deref;
+use std::ops::{Deref, DerefMut};
 use std::rc::Rc;
 
 /// An return type from XML elements retrieval methods. It's an enum of all supported values, that
@@ -63,7 +63,7 @@ impl XmlElement {
         let tag = inner
             .name
             .as_ref()
-            .map(|s| s.as_str())
+            .map(|s| s.as_ref())
             .unwrap_or(&"UNDEFINED");
         write!(&mut s, "<{}", tag).unwrap();
         let attributes = Attributes(inner.entries());
@@ -207,7 +207,7 @@ impl XmlElement {
     /// If `index` is equal to length of current XML element, new element will be inserted as a last
     /// child.
     /// This method will panic if `index` is greater than the length of current XML element.
-    pub fn insert_elem<S: ToString>(
+    pub fn insert_elem<S: Into<Rc<str>>>(
         &self,
         txn: &mut Transaction,
         index: u32,
@@ -234,13 +234,13 @@ impl XmlElement {
 
     /// Pushes a new [XmlElement] with a given tag `name` as the last child of a current one and
     /// returns it.
-    pub fn push_elem_back<S: ToString>(&self, txn: &mut Transaction, name: S) -> XmlElement {
+    pub fn push_elem_back<S: Into<Rc<str>>>(&self, txn: &mut Transaction, name: S) -> XmlElement {
         self.0.push_elem_back(txn, name)
     }
 
     /// Pushes a new [XmlElement] with a given tag `name` as the first child of a current one and
     /// returns it.
-    pub fn push_elem_front<S: ToString>(&self, txn: &mut Transaction, name: S) -> XmlElement {
+    pub fn push_elem_front<S: Into<Rc<str>>>(&self, txn: &mut Transaction, name: S) -> XmlElement {
         self.0.push_elem_front(txn, name)
     }
 
@@ -287,6 +287,12 @@ impl AsRef<Branch> for XmlElement {
     }
 }
 
+impl AsMut<Branch> for XmlElement {
+    fn as_mut(&mut self) -> &mut Branch {
+        self.0.as_mut()
+    }
+}
+
 impl From<BranchPtr> for XmlElement {
     fn from(inner: BranchPtr) -> Self {
         XmlElement(XmlFragment::new(inner))
@@ -365,15 +371,13 @@ impl XmlFragment {
         s
     }
 
-    pub fn insert_elem<S: ToString>(
+    pub fn insert_elem<S: Into<Rc<str>>>(
         &self,
         txn: &mut Transaction,
         index: u32,
         name: S,
     ) -> XmlElement {
-        let ptr = self
-            .0
-            .insert_at(txn, index, PrelimXml::Elem(name.to_string()));
+        let ptr = self.0.insert_at(txn, index, PrelimXml::Elem(name.into()));
         let item = ptr.as_item().unwrap();
         if let ItemContent::Type(inner) = &item.content {
             XmlElement::from(BranchPtr::from(inner))
@@ -399,12 +403,12 @@ impl XmlFragment {
         }
     }
 
-    pub fn push_elem_back<S: ToString>(&self, txn: &mut Transaction, name: S) -> XmlElement {
+    pub fn push_elem_back<S: Into<Rc<str>>>(&self, txn: &mut Transaction, name: S) -> XmlElement {
         let len = self.len();
         self.insert_elem(txn, len, name)
     }
 
-    pub fn push_elem_front<S: ToString>(&self, txn: &mut Transaction, name: S) -> XmlElement {
+    pub fn push_elem_front<S: Into<Rc<str>>>(&self, txn: &mut Transaction, name: S) -> XmlElement {
         self.insert_elem(txn, 0, name)
     }
 
@@ -452,6 +456,12 @@ impl AsRef<Branch> for XmlFragment {
     }
 }
 
+impl AsMut<Branch> for XmlFragment {
+    fn as_mut(&mut self) -> &mut Branch {
+        self.0.deref_mut()
+    }
+}
+
 /// An iterator over [XmlElement] successors, working in a recursive depth-first manner.
 pub struct TreeWalker<'a> {
     current: Option<&'a Item>,
@@ -803,6 +813,12 @@ impl AsRef<Branch> for XmlText {
     }
 }
 
+impl AsMut<Branch> for XmlText {
+    fn as_mut(&mut self) -> &mut Branch {
+        self.0.as_mut()
+    }
+}
+
 impl From<BranchPtr> for XmlText {
     fn from(inner: BranchPtr) -> Self {
         XmlText(Text::from(inner))
@@ -817,8 +833,8 @@ impl Into<XmlText> for Text {
 
 /// Event generated by [XmlText::observe] method. Emitted during transaction commit phase.
 pub struct XmlTextEvent {
+    pub(crate) current_target: BranchPtr,
     target: XmlText,
-    current_target: BranchPtr,
     delta: UnsafeCell<Option<Vec<Delta>>>,
     keys: UnsafeCell<Result<HashMap<Rc<str>, EntryChange>, HashSet<Option<Rc<str>>>>>,
 }
@@ -877,7 +893,7 @@ impl XmlTextEvent {
 }
 
 enum PrelimXml {
-    Elem(String),
+    Elem(Rc<str>),
     Text,
 }
 
@@ -934,8 +950,8 @@ fn parent(inner: BranchPtr) -> Option<XmlElement> {
 
 /// Event generated by [XmlElement::observe] method. Emitted during transaction commit phase.
 pub struct XmlEvent {
+    pub(crate) current_target: BranchPtr,
     target: XmlElement,
-    current_target: BranchPtr,
     change_set: UnsafeCell<Option<Box<ChangeSet<Change>>>>,
     keys: UnsafeCell<Result<HashMap<Rc<str>, EntryChange>, HashSet<Option<Rc<str>>>>>,
     children_changed: bool,
@@ -1018,7 +1034,7 @@ mod test {
     use crate::types::{Change, EntryChange, Value};
     use crate::updates::decoder::Decode;
     use crate::updates::encoder::{Encoder, EncoderV1};
-    use crate::{Doc, Update};
+    use crate::{Doc, StateVector, Update};
     use lib0::any::Any;
     use std::cell::RefCell;
     use std::collections::HashMap;
@@ -1035,7 +1051,7 @@ mod test {
         let d2 = Doc::with_client_id(1);
         let mut t2 = d2.transact();
         let xml2 = t2.get_xml_element("xml");
-        let u = t1.encode_update_v1(); // d1.encode_state_as_update_v1
+        let u = d1.encode_state_as_update_v1(&StateVector::default());
         t2.apply_update(Update::decode_v1(u.as_slice()));
         assert_eq!(xml2.get_attribute("height"), Some("10".to_string()));
     }
@@ -1129,7 +1145,7 @@ mod test {
         let expected = "<UNDEFINED>hello<p></p></UNDEFINED>";
         assert_eq!(r1.to_string(), expected);
 
-        let u1 = t1.encode_update_v1(); //d1.encode_state_as_update_v1(&t1);
+        let u1 = d1.encode_state_as_update_v1(&StateVector::default());
 
         let d2 = Doc::with_client_id(2);
         let mut t2 = d2.transact();
@@ -1164,7 +1180,7 @@ mod test {
             1, 3, 1, 0, 7, 1, 4, 114, 111, 111, 116, 6, 4, 0, 1, 0, 5, 104, 101, 108, 108, 111,
             135, 1, 0, 3, 1, 112, 0,
         ];
-        let u1 = t1.encode_update_v1(); //d1.encode_state_as_update_v1(&t1);
+        let u1 = d1.encode_state_as_update_v1(&StateVector::default());
         assert_eq!(u1.as_slice(), expected);
     }
 
